@@ -41,14 +41,13 @@
 
 #include "log.h"
 #include "handler.h"
-#include "handler_dirlist.h"
-#include "handler_file.h"
 #include "connection.h"
 #include "buffer.h"
-#include "plugin_table_entry.h"
+#include "handler_table_entry.h"
 #include "encoder_table.h"
 #include "server.h"
 
+
 ret_t
 cherokee_connection_new  (cherokee_connection_t **cnt)
 {
@@ -57,20 +56,21 @@ cherokee_connection_new  (cherokee_connection_t **cnt)
 	cherokee_buffer_new (&n->buffer);
 	   
 	INIT_LIST_HEAD((list_t*)n);
-	n->tcp_cork        = 0;
-	n->error_code      = http_ok;
-	n->phase           = phase_reading_header;
-	n->method          = http_unknown;
-	n->version         = http_version_unknown;
-	n->handler         = NULL; 
-	n->encoder         = NULL;
-	n->arguments       = NULL;
-	n->logger_ref      = NULL;
-	n->keep_alive      = 0;
-	n->timeout         = time(NULL) + 15;   // CHECK ME !!
-	n->range_start     = 0;
-	n->range_end       = 0;
-	n->vserver         = NULL;
+	n->tcp_cork    = 0;
+	n->error_code  = http_ok;
+	n->phase       = phase_reading_header;
+	n->method      = http_unknown;
+	n->version     = http_version_unknown;
+	n->handler     = NULL; 
+	n->encoder     = NULL;
+	n->arguments   = NULL;
+	n->logger_ref  = NULL;
+	n->keep_alive  = 0;
+	n->timeout     = time(NULL) + 15;   // CHECK ME !!
+	n->range_start = 0;
+	n->range_end   = 0;
+	n->vserver     = NULL;
+	n->log_at_end  = 0;
 
 	cherokee_buffer_new (&n->local_directory);
 	cherokee_buffer_new (&n->web_directory);
@@ -129,8 +129,9 @@ cherokee_connection_clean (cherokee_connection_t *cnt)
 	   cnt->range_start  = 0;
 	   cnt->range_end    = 0;
 	   cnt->logger_ref   = NULL;
-	   cnt->tcp_cork     = 0;
 	   cnt->vserver      = NULL;
+	   cnt->tcp_cork     = 0;
+	   cnt->log_at_end   = 0;
 
 	   if (cnt->handler != NULL) {
 		   cherokee_handler_free (cnt->handler);
@@ -199,6 +200,23 @@ add_error_code_string_to_buffer (cherokee_connection_t *cnt)
 }
 
 
+static ret_t
+send_buffer_unsafe (cherokee_connection_t *cnt)
+{
+	int ret;
+
+	ret = write (SOCKET_FD(cnt->socket), cnt->buffer->buf, cnt->buffer->len);
+	cherokee_buffer_make_empty (cnt->buffer);
+
+	if (ret <= 0) {
+		cnt->keep_alive = 0;
+		return ret_error;
+	}
+
+	return ret_ok;
+}
+
+
 ret_t
 cherokee_connection_send_header (cherokee_connection_t *cnt)
 {
@@ -633,7 +651,7 @@ cherokee_connection_is_userdir (cherokee_connection_t *cnt)
 
 
 ret_t
-cherokee_connection_build_local_directory (cherokee_connection_t *cnt, cherokee_virtual_server_t *vsrv, cherokee_plugin_table_entry_t *entry)
+cherokee_connection_build_local_directory (cherokee_connection_t *cnt, cherokee_virtual_server_t *vsrv, cherokee_handler_table_entry_t *entry)
 {
 	ret_t ret;
 
@@ -668,35 +686,30 @@ ret_t
 cherokee_connection_build_local_directory_userdir (cherokee_connection_t *cnt, char *userdir)
 {
 	struct passwd *pwd;	
-	char          *end;
-	char          *begin;
+	char          *begin, *end;
 
 	begin = &cnt->request->buf[2];
+	end   = &cnt->request->buf[cnt->request->len-1];
 
-	/* Find user name endding
+	/* It's an special case. The request is something like:
+	 * 	http://www.alobbs.com/~alo/dir
+	 * and Cherokee should redirect it to:
+	 * 	http://www.alobbs.com/~alo/dir/
 	 */
-	end = index (begin, '/');
-
-	if (end == NULL) {
-
-		end = index (begin, '\0');
-
-		/* It's an special case. The request is something like:
-		 * 	http://www.alobbs.com/~alo
-		 * and Cherokee should redirect it to:
-		 * 	http://www.alobbs.com/~alo/
-		 */
-
+	if (*end != '/') {
 		cherokee_buffer_ensure_size (cnt->redirect, cnt->request->len+2);
 		cherokee_buffer_add (cnt->redirect, cnt->request->buf, cnt->request->len);
 		cherokee_buffer_add (cnt->redirect, "/", 1);
 
 		cnt->error_code = http_moved_permanently;
+		return ret_error;
 	}
-	
+
+	/* Find user name endding
+	 */
+	end = index (begin, '/');
 	if (end == NULL)
 		return ret_error;
-	 
 		
 	/* Copy the username
 	 */
@@ -828,13 +841,13 @@ cherokee_connection_get_request (cherokee_connection_t *cnt)
 
 
 ret_t 
-cherokee_connection_get_plugin_entry (cherokee_connection_t *cnt, cherokee_plugin_table_t *plugins, cherokee_plugin_table_entry_t **plugin_entry)
+cherokee_connection_get_plugin_entry (cherokee_connection_t *cnt, cherokee_handler_table_t *plugins, cherokee_handler_table_entry_t **plugin_entry)
 {
 	ret_t ret;
 
 	/* Look for the handler "*_new" function
 	 */
-	ret = cherokee_plugin_table_get (plugins, cnt->request->buf, plugin_entry, cnt->web_directory);
+	ret = cherokee_handler_table_get (plugins, cnt->request->buf, plugin_entry, cnt->web_directory);
 	if (ret != ret_ok) {
 		cnt->error_code = http_internal_error;
 		return ret_error;
@@ -845,10 +858,12 @@ cherokee_connection_get_plugin_entry (cherokee_connection_t *cnt, cherokee_plugi
 
 
 ret_t 
-cherokee_connection_create_handler (cherokee_connection_t *cnt, cherokee_plugin_table_entry_t *plugin_entry)
+cherokee_connection_create_handler (cherokee_connection_t *cnt, cherokee_handler_table_entry_t *plugin_entry)
 {
 	ret_t ret;
 
+	return_if_fail (plugin_entry->handler_new_func != NULL, ret_error);
+
 	/* Create and assign a handler object
 	 */
 	ret = (plugin_entry->handler_new_func) ((void **)&cnt->handler, cnt, plugin_entry->properties);
@@ -985,23 +1000,6 @@ cherokee_connection_open_request (cherokee_connection_t *cnt)
 }
 
 
-static ret_t
-send_buffer_unsafe (cherokee_connection_t *cnt)
-{
-	int r;
-
-	r = write (SOCKET_FD(cnt->socket), cnt->buffer->buf, cnt->buffer->len);
-	cherokee_buffer_make_empty  (cnt->buffer);
-
-	if (r <= 0) {
-		cnt->keep_alive = 0;
-		return ret_error;
-	}
-
-	return ret_ok;
-}
-
-
 ret_t
 cherokee_connection_send_response_page_hardcoded (cherokee_connection_t *cnt)
 {
