@@ -42,10 +42,10 @@
 #include "common.h"
 #include "buffer.h"
 #include "handler.h"
-#include "plugin_table.h"
+#include "handler_table.h"
 #include "virtual_server.h"
 #include "encoder_table.h"
-#include "plugin_table_entry.h"
+#include "handler_table_entry.h"
 #include "socket.h"
 
 
@@ -136,8 +136,8 @@ ret_t cherokee_connection_open_request  (cherokee_connection_t *cnt);
 ret_t cherokee_connection_reading_check (cherokee_connection_t *cnt);
 ret_t cherokee_connection_step          (cherokee_connection_t *cnt);
 
-ret_t cherokee_connection_get_plugin_entry (cherokee_connection_t *cnt, cherokee_plugin_table_t *plugins, cherokee_plugin_table_entry_t **plugin_entry);
-ret_t cherokee_connection_create_handler   (cherokee_connection_t *cnt, cherokee_plugin_table_entry_t *plugin_entry);
+ret_t cherokee_connection_get_plugin_entry (cherokee_connection_t *cnt, cherokee_handler_table_t *plugins, cherokee_handler_table_entry_t **plugin_entry);
+ret_t cherokee_connection_create_handler   (cherokee_connection_t *cnt, cherokee_handler_table_entry_t *plugin_entry);
 
 /* 	Headers
  */
@@ -154,7 +154,7 @@ ret_t cherokee_connection_log_delayed  (cherokee_connection_t *cnt);
 
 
 int   cherokee_connection_is_userdir                    (cherokee_connection_t  *cnt);
-ret_t cherokee_connection_build_local_directory         (cherokee_connection_t  *cnt, cherokee_virtual_server_t *vsrv, cherokee_plugin_table_entry_t *entry);
+ret_t cherokee_connection_build_local_directory         (cherokee_connection_t  *cnt, cherokee_virtual_server_t *vsrv, cherokee_handler_table_entry_t *entry);
 ret_t cherokee_connection_build_local_directory_userdir (cherokee_connection_t  *cnt, char *userdir);
 
 
