@@ -23,6 +23,7 @@
  * USA
  */
 
+#include "module.h"
 #include "encoder_gzip.h"
 
 
@@ -40,6 +41,11 @@ static char gzip_header[gzip_header_len] = {0x1F, 0x8B,
  *
  */
 
+cherokee_module_info_t cherokee_gzip_info = {
+	cherokee_encoder,            /* type     */
+	cherokee_encoder_gzip_new    /* new func */
+};
+
 ret_t 
 cherokee_encoder_gzip_new (cherokee_encoder_gzip_t **encoder)
 {
