@@ -131,7 +131,7 @@ fdpoll_epoll_new (cherokee_fdpoll_t **fdp)
 
 	   n->ep_fd = epoll_create (n->nfiles + 1);
 	   if (n->ep_fd < 0) {
-		   PRINT_ERROR ("Fatal Error: Couldn't get /dev/epoll descriptor: epoll_create(%d)\n", n->nfiles + 1);
+		   PRINT_ERROR ("Fatal Error: Couldn't get /dev/epoll descriptor: epoll_create(%d) -> %d\n", n->nfiles+1, n->ep_fd);
 		   exit (EXIT_EPOLL_CREATE);
 	   }
 
@@ -224,8 +224,6 @@ fdpoll_epoll_set_mode (cherokee_fdpoll_t *fdp, int fd, int rw)
 	}
 
 	UNLOCK(fdp);
-
-	return ret_ok;
 }
 
 ret_t
@@ -274,12 +272,16 @@ fdpoll_epoll_check (cherokee_fdpoll_t *fdp, int fd, int rw)
 
 	
 	if ((fdidx == -1) ||
-	    (fdp->ep_events[fdidx].data.fd != fd) || 
-	    (fdp->ep_events[fdidx].events & EPOLLERR))
+	    (fdp->ep_events[fdidx].data.fd != fd))
 	{
 		return 0;
 	}
 
+	if (fdp->ep_events[fdidx].events == (EPOLLHUP | EPOLLERR)) 
+	{
+		return -1;
+	}
+
 //	switch (fdp->fd_rw[fd])
 	switch (rw)
 	{
@@ -308,9 +310,11 @@ fdpoll_epoll_reset (cherokee_fdpoll_t *fdp, int fd)
 /* poll()                                                              */
 /*                                                                     */
 /* #include <sys/poll.h>                                               */
-/*                                                                     */
 /* int poll(struct pollfd *ufds, unsigned int nfds, int timeout);      */
 /*                                                                     */
+/* Info:                                                               */
+/* http://www.xmailserver.org/linux-patches/nio-improve.html           */
+/*                                                                     */
 /***********************************************************************/
 #ifdef USE_POLL
 
