@@ -30,6 +30,7 @@
 #include <ctype.h>
 #include <stdarg.h>
 
+#include "module.h"
 #include "handler_cgi.h"
 #include "connection.h"
 
@@ -40,6 +41,13 @@
 static char *method[]  = {"GET", "POST", "HEAD", NULL};
 
 
+cherokee_module_info_t cherokee_cgi_info = {
+	cherokee_handler,           /* type     */
+	cherokee_handler_cgi_new    /* new func */
+};
+
+
+
 void _LOG(const char* msg, ...)
 {
 #ifndef SILENT
