@@ -27,6 +27,7 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
+#include "module.h"
 #include "connection.h"
 #include "handler_common.h"
 #include "handler_file.h"
@@ -34,6 +35,12 @@
 #include "server.h"
 #include "list_ext.h"
 
+
+cherokee_module_info_t cherokee_common_info = {
+	cherokee_handler,              /* type     */
+	cherokee_handler_common_new    /* new func */
+};
+
 ret_t 
 cherokee_handler_common_new (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties)
 {
