@@ -32,6 +32,7 @@
 #include "mime.h"
 #include "handler_file.h"
 #include "connection.h"
+#include "module.h"
 
 #if defined(LINUX_SENDFILE_API) || defined(SOLARIS_SENDFILE_API)
 # include <sys/sendfile.h>
@@ -47,6 +48,11 @@
 #endif
 
 
+cherokee_module_info_t cherokee_file_info = {
+	cherokee_handler,            /* type     */
+	cherokee_handler_file_new    /* new func */
+};
+
 ret_t
 cherokee_handler_file_new  (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *properties)
 {
