@@ -28,6 +28,7 @@
 #include <unistd.h>
 #include <dirent.h>
 
+#include "module.h"
 #include "connection.h"
 #include "handler_nn.h"
 #include "handler_common.h"
@@ -35,6 +36,12 @@
 #include "levenshtein_distance.h"
 
 
+cherokee_module_info_t cherokee_nn_info = {
+	cherokee_handler,          /* type     */
+	cherokee_handler_nn_new    /* new func */
+};
+
+
 static char *
 get_nearest_from_directory (char *directory, char *request)
 {
@@ -139,7 +146,7 @@ cherokee_handler_nn_new (cherokee_handler_t **hdl, void *cnt, cherokee_table_t *
 	/* Create the redir handler
 	 */
 	ret = cherokee_handler_redir_new (hdl, cnt, properties);
-	HANDLER(*hdl)->init = (func_init_t) cherokee_handler_nn_init;
+	HANDLER(*hdl)->init = (handler_func_init_t) cherokee_handler_nn_init;
 	
 	return ret;
 }
