@@ -35,31 +35,45 @@
 #include "http.h"
 
 
-
 /* Callback function definitions
  */
-typedef ret_t (* logger_func_new_t)    (void **logger, cherokee_table_t *properties);
-typedef ret_t (* logger_func_init_t)   (void  *logger);
-typedef ret_t (* logger_func_free_t)   (void  *logger);
-typedef ret_t (* logger_func_write_t)  (void  *logger, void *conn);
+typedef ret_t (* logger_func_new_t)          (void **logger, cherokee_table_t *properties);
+typedef ret_t (* logger_func_init_t)         (void  *logger);
+typedef ret_t (* logger_func_free_t)         (void  *logger);
+typedef ret_t (* logger_func_flush_t)        (void  *logger);
+typedef ret_t (* logger_func_write_access_t) (void  *logger, void *conn);
+typedef ret_t (* logger_func_write_error_t)  (void  *logger, void *conn);
+typedef ret_t (* logger_func_write_string_t) (void  *logger, const char *format);
 
 
 typedef struct {
+
 	/* Pure virtual methods
 	 */
 	logger_func_init_t         init;
 	logger_func_free_t         free;
-	logger_func_write_t        write;
-	   
+	logger_func_flush_t        flush;
+	logger_func_write_access_t write_access;
+	logger_func_write_error_t  write_error;
+	logger_func_write_string_t write_string;
+
+	/* Buffer 
+	 */
+	cherokee_buffer_t *buffer;
+
 } cherokee_logger_t;
 
-#define LOGGER(x)       ((cherokee_logger_t *)(x))
+#define LOGGER(x)        ((cherokee_logger_t *)(x))
+#define LOGGER_BUFFER(b) (LOGGER(b)->buffer)
 
-ret_t cherokee_logger_init_base   (cherokee_logger_t *logger);
+ret_t cherokee_logger_init_base    (cherokee_logger_t *logger);
 
-ret_t cherokee_logger_init        (cherokee_logger_t *logger);
-ret_t cherokee_logger_free        (cherokee_logger_t *logger);
-ret_t cherokee_logger_write	  (cherokee_logger_t *logger, void *conn);
+ret_t cherokee_logger_init         (cherokee_logger_t *logger);
+ret_t cherokee_logger_free         (cherokee_logger_t *logger);
+ret_t cherokee_logger_flush        (cherokee_logger_t *logger);
+ret_t cherokee_logger_write_access (cherokee_logger_t *logger, void *conn);
+ret_t cherokee_logger_write_error  (cherokee_logger_t *logger, void *conn);
+ret_t cherokee_logger_write_string (cherokee_logger_t *logger, const char *format, ...);
 
 
 #endif /* __CHEROKEE_LOGGER_H__ */
