@@ -45,6 +45,7 @@
 #include "logger_ncsa.h"
 #include "connection.h"
 #include "server.h"
+#include "module.h"
 
 #ifdef HAVE_PTHREAD
 pthread_mutex_t buffer_lock = PTHREAD_MUTEX_INITIALIZER;
@@ -67,6 +68,11 @@ static char *month[]   = {"Jan", "Feb", "Mar", "Apr", "May", "Jun",
 #endif
 
 
+cherokee_module_info_t cherokee_ncsa_info = {
+	cherokee_logger,            /* type     */
+	cherokee_logger_ncsa_new    /* new func */
+};
+
 ret_t
 cherokee_logger_ncsa_new  (cherokee_logger_t **logger, cherokee_table_t *properties)
 {
