@@ -45,7 +45,7 @@ typedef struct {
 	cherokee_logger_t logger;
 
 	char *accesslog_filename;
-	char *errorlog_filename;	
+	char *errorlog_filename;
 
 	FILE *accesslog_fd;
 	FILE *errorlog_fd;
@@ -58,8 +58,11 @@ ret_t cherokee_logger_ncsa_new (cherokee_logger_t **logger, cherokee_table_t *pr
 
 /* virtual methods implementation
  */
-ret_t cherokee_logger_ncsa_init  (cherokee_logger_ncsa_t *logger);
-ret_t cherokee_logger_ncsa_free  (cherokee_logger_ncsa_t *logger);
-ret_t cherokee_logger_ncsa_write (cherokee_logger_ncsa_t *logger, cherokee_connection_t *conn);
+ret_t cherokee_logger_ncsa_init         (cherokee_logger_ncsa_t *logger);
+ret_t cherokee_logger_ncsa_free         (cherokee_logger_ncsa_t *logger);
+ret_t cherokee_logger_ncsa_flush        (cherokee_logger_ncsa_t *logger);
+ret_t cherokee_logger_ncsa_write_access (cherokee_logger_ncsa_t *logger, cherokee_connection_t *conn);
+ret_t cherokee_logger_ncsa_write_error  (cherokee_logger_ncsa_t *logger, cherokee_connection_t *conn);
+ret_t cherokee_logger_ncsa_write_string (cherokee_logger_ncsa_t *logger, const char *string);
 
 #endif /* __CHEROKEE_LOGGER_NCSA_COMMON_H__ */
