@@ -36,7 +36,7 @@ static void
 restart_server (int code)
 {	
 	cherokee_server_handle_HUP (srv);
-	printf ("Cherokee reloaded\n");
+	printf ("main.c: restart_server\n");
 }
 
 static void
