@@ -53,6 +53,9 @@ cherokee_server_new  (cherokee_server_t **srv)
 	 */
 	CHEROKEE_NEW_STRUCT(n, server);
 	
+	n->wanna_exit      = 0;
+	n->config_filename = NULL;
+	
 	/* Sockets
 	 */
 	n->socket = -1;
@@ -102,6 +105,10 @@ cherokee_server_new  (cherokee_server_t **srv)
 	cherokee_virtual_server_new (&n->vserver_default);
 	return_if_fail (n->vserver_default!=NULL, ret_nomem);
 
+	/* Module loader
+	 */
+	cherokee_module_loader_new (&n->loader);
+	return_if_fail (n->loader != NULL, ret_nomem);	
 		
 	/* Encoders 
 	 */
@@ -419,7 +426,7 @@ cherokee_server_clean (cherokee_server_t *srv)
 	}
 
 	if (srv->userdir_handler != NULL) {
-		cherokee_plugin_table_entry_free (srv->userdir_handler);
+		cherokee_handler_table_entry_free (srv->userdir_handler);
 		srv->userdir_handler = NULL;
 	}
 
@@ -428,6 +435,10 @@ cherokee_server_clean (cherokee_server_t *srv)
 		srv->chroot = NULL;
 	}
 	
+	/* Clean the loader
+	 */
+	// TODO
+
 	/* Clean the encoders table
 	 */
 	cherokee_encoder_table_clean (srv->encoders);
@@ -449,7 +460,8 @@ cherokee_server_clean (cherokee_server_t *srv)
 	 */
 	cherokee_list_free (&srv->index_list, free);
 	INIT_LIST_HEAD(&srv->index_list);
- 
+
+ 	srv->wanna_exit     = 0;
 	srv->hideversion    = 0;
 	srv->hideservername = 0;
 	srv->keepalive_max  = MAX_KEEP_ALIVE;
@@ -476,6 +488,7 @@ cherokee_server_free (cherokee_server_t *srv)
 	cherokee_table_foreach (srv->vservers, for_each_func_free_vserver);
 	cherokee_table_free (srv->vservers);
 
+	cherokee_module_loader_free (srv->loader);
 
 	if (srv->listen_to != NULL) {
 		free (srv->listen_to);
@@ -493,7 +506,7 @@ cherokee_server_free (cherokee_server_t *srv)
 	}
 
 	if (srv->userdir_handler != NULL) {
-		cherokee_plugin_table_entry_free (srv->userdir_handler);
+		cherokee_handler_table_entry_free (srv->userdir_handler);
 		srv->userdir_handler = NULL;
 	}
 	
@@ -502,6 +515,11 @@ cherokee_server_free (cherokee_server_t *srv)
 		srv->chroot = NULL;
 	}
 
+	if (srv->config_filename != NULL) {
+		free (srv->config_filename);
+		srv->config_filename = NULL;
+	}
+
 	free (srv);
 	
 	return ret_ok;
@@ -511,8 +529,9 @@ cherokee_server_free (cherokee_server_t *srv)
 static inline int
 look_for_new_connection (cherokee_server_t *srv)
 {
-	int new_socket;
+	ret_t   ret;
 	list_t *thread;
+	int     new_socket;
 
 	cherokee_thread_t     *lazy_thread;
 	cherokee_connection_t *new_conn;
@@ -543,7 +562,11 @@ look_for_new_connection (cherokee_server_t *srv)
 
 	/* Accept the connection in the new socket
 	 */
-	cherokee_socket_accept (CONN_SOCK(new_conn), srv->socket);
+	ret = cherokee_socket_accept (CONN_SOCK(new_conn), srv->socket);
+	if (ret < ret_ok) {
+		cherokee_thread_set_reusable_connection (lazy_thread, new_conn);
+		return ret;
+	}
 
 	/* Add the configured connection to the thread
 	 */
@@ -573,6 +596,42 @@ flush_logs (cherokee_server_t *srv)
 }
 
 
+ret_t 
+cherokee_server_reinit (cherokee_server_t *srv)
+{
+	ret_t  ret;
+	
+	printf ("cherokee_server_reinit\n");
+
+	if (srv->chrooted) {
+		fprintf (stderr, 
+			 "WARNING: Chrooted cherokee cannot be reloaded. "
+			 "Please, stop and restart it again.\n");
+		return ret_ok;
+	}
+
+
+	ret = cherokee_server_clean (srv);
+	if (ret != ret_ok) {
+		exit(EXIT_SERVER_CLEAN);
+	}
+
+	ret = cherokee_server_read_config_file (srv, NULL);
+	if (ret != ret_ok) {
+		exit(EXIT_SERVER_READ_CONFIG);
+	}
+
+	ret = cherokee_server_init (srv);
+	if (ret != ret_ok) {
+		exit(EXIT_SERVER_INIT);	
+	}
+
+	printf ("cherokee_server_reinit2\n");
+
+	return ret_ok;
+}
+
+
 void
 cherokee_server_step (cherokee_server_t *srv)
 {
@@ -599,35 +658,64 @@ cherokee_server_step (cherokee_server_t *srv)
 		flush_logs (srv);
 		srv->log_flush_next = srv->bogo_now + srv->log_flush_elapse;
 	}
+
+	/* Wanna exit?
+	 */
+	if (srv->wanna_exit) {
+		cherokee_server_reinit (srv);
+		srv->wanna_exit = 0;
+		printf ("Cherokee reloaded\n");
+	}
 }
 
 
 ret_t 
 cherokee_server_read_config_file (cherokee_server_t *srv, char *filename)
 {
-	int error;
-
+	int   error;
+	void *bufstate;
 	extern FILE *yyin;
 	extern int yyparse (void *);
 
+	/* Maybe set a default configuration filename
+	 */
+	if (filename == NULL) {
+		filename = (srv->config_filename)? srv->config_filename : CHEROKEE_CONFDIR"/cherokee.conf";
+
+	} else {
+		/* Maybe free an old filename
+		 */
+		if (srv->config_filename != NULL) {
+			free (srv->config_filename);
+		}
+		
+		/* Store last configuration filename
+		 */
+		srv->config_filename = strdup(filename);
+	}
+
 	/* Set the file to read
 	 */
 	yyin = fopen (filename, "r");
 	if (yyin == NULL) {
 		PRINT_ERROR("Can't read the configuration file: '%s'\n", filename);
+		return ret_error;
 	}
 
 	/* Cooooome on :-)
 	 */
+	yyrestart(yyin);
+
+//	error = yyparse ((void *)srv);
+	
+	bufstate = (void *) yy_create_buffer (yyin, 65535);
+	yy_switch_to_buffer(bufstate);
 	error = yyparse ((void *)srv);
+	yy_delete_buffer (bufstate);
 
-	if (yyin != NULL)
-		fclose (yyin);
+	fclose (yyin);
 
-	if (error != 0)
-		return ret_error;
-
-	return ret_ok;
+	return (error)? ret_error : ret_ok;
 }
 
 
@@ -649,41 +737,15 @@ cherokee_server_read_config_string (cherokee_server_t *srv, char *config_string)
 
 	yy_delete_buffer (bufstate);
 
-	if (error != 0)
-		return ret_error;
-
-	return ret_ok;
+	return (error)? ret_error : ret_ok;
 }
 
 
 ret_t 
 cherokee_server_handle_HUP (cherokee_server_t *srv)
 {
-	ret_t ret;
-
-	if (srv->chrooted) {
-		fprintf (stderr, 
-			 "WARNING: Chrooted cherokee cannot be reloaded. "
-			 "Please, stop and restart it again.\n");
-		return ret_ok;
-	}
-
-
-	ret = cherokee_server_clean (srv);
-	if (ret != ret_ok) {
-		exit(EXIT_SERVER_CLEAN);
-	}
-
-	ret = cherokee_server_read_config_file (srv, CHEROKEE_CONFDIR"/cherokee.conf");
-	if (ret != ret_ok) {
-		exit(EXIT_SERVER_READ_CONFIG);
-	}
-
-	ret = cherokee_server_init (srv);
-	if (ret != ret_ok) {
-		exit(EXIT_SERVER_INIT);	
-	}
-
+	srv->wanna_exit = 1;
+	printf ("cherokee_server_handle_HUP\n");
 	return ret_ok;
 }
 
