@@ -177,10 +177,15 @@ process_active_connections (cherokee_thread_t *thd)
 
 		/* Inspect the file descriptor
 		 */
-		if (cherokee_fdpoll_check (thd->fdpoll, 
-					   SOCKET_FD(conn->socket), 
-					   SOCKET_STATUS(conn->socket)) == 0) 
-		{
+		ret = cherokee_fdpoll_check (thd->fdpoll, 
+					     SOCKET_FD(conn->socket), 
+					     SOCKET_STATUS(conn->socket));
+
+		switch (ret) {
+		case -1:
+			purge_closed_connection(thd, conn);
+			continue;
+		case 0:
 			continue;
 		}
 
@@ -205,6 +210,7 @@ process_active_connections (cherokee_thread_t *thd)
 			if (ret != ret_ok) {
 //				conn_set_mode (thd, conn, stat_writing);
 				conn_set_mode (thd, conn, socket_writing);
+				conn->vserver = srv->vserver_default;
 				conn->phase = phase_add_headers;
 				continue;
 			}
@@ -223,9 +229,12 @@ process_active_connections (cherokee_thread_t *thd)
 
 		case phase_processing_header: {
 			
-			cherokee_virtual_server_t *vserver = NULL;
-			cherokee_plugin_table_entry_t *plugin_entry = NULL;
+			cherokee_handler_table_entry_t *plugin_entry = NULL;
 			
+			/* Set the default virtual server
+			 */
+			conn->vserver = srv->vserver_default;
+
 			/* Get the request
 			 */
 			ret = cherokee_connection_get_request (conn);
@@ -234,21 +243,21 @@ process_active_connections (cherokee_thread_t *thd)
 				continue;
 			}
 			
-			
-			/* Get the virtual host
+			/* Get the virtual host and maybe set a new vserver reference
 			 */
 			if (conn->host->len > 0) {
+				cherokee_virtual_server_t *vserver;
+
 				vserver = cherokee_table_get_val (srv->vservers, conn->host->buf);
+
+				if (vserver != NULL) {
+					conn->vserver = vserver;
+				}
 			}
-			if (vserver == NULL) {
-				vserver = srv->vserver_default;
-			}
-			conn->vserver = vserver;
-			
 
 			/* Set the logger of the connection
 			 */
-			conn->logger_ref = vserver->logger;
+			conn->logger_ref = CONN_VSRV(conn)->logger;
 
 
 			/* Build local request string
@@ -270,12 +279,12 @@ process_active_connections (cherokee_thread_t *thd)
 					continue;
 				}
 			} else {
-				ret = cherokee_connection_get_plugin_entry (conn, vserver->plugins, &plugin_entry);
+				ret = cherokee_connection_get_plugin_entry (conn, CONN_VSRV(conn)->plugins, &plugin_entry);
 				if (ret != ret_ok) {
 					conn->phase = phase_add_headers;
 					continue;
 				}
-				ret = cherokee_connection_build_local_directory (conn, vserver, plugin_entry);
+				ret = cherokee_connection_build_local_directory (conn, CONN_VSRV(conn), plugin_entry);
 			}
 			if (ret != ret_ok) {
 				conn->phase = phase_add_headers;
@@ -365,13 +374,7 @@ process_active_connections (cherokee_thread_t *thd)
 
 			/* Log the connection
 			 */
-			cherokee_connection_log_or_delay (conn);
-
-/*			if (conn->logger_ref != NULL) {
-				cherokee_logger_write_access (conn->logger_ref, conn);
-			}
-*/
-			
+			cherokee_connection_log_or_delay (conn);			
 			conn->phase = phase_steping;
 			
 		case phase_steping: {
@@ -497,6 +500,13 @@ cherokee_thread_get_new_connection (cherokee_thread_t *thd, cherokee_connection_
 }
 
 
+ret_t 
+cherokee_thread_set_reusable_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
+{
+	list_add ((list_t *)conn, &thread->reuse_list);
+}
+
+
 ret_t 
 cherokee_thread_add_connection (cherokee_thread_t *thd, cherokee_connection_t  *conn)
 {
