@@ -53,7 +53,7 @@ cherokee_virtual_server_new (cherokee_virtual_server_t **vserver)
 	 */
 	init_gnutls(vsrv);
 
-	cherokee_plugin_table_new (&vsrv->plugins);
+	cherokee_handler_table_new (&vsrv->plugins);
 	return_if_fail (vsrv->plugins!=NULL, ret_nomem);	   
 
 	*vserver = vsrv;
@@ -86,7 +86,7 @@ cherokee_virtual_server_free (cherokee_virtual_server_t *vserver)
 		vserver->logger_props = NULL;
 	}
 	
-	cherokee_plugin_table_free (vserver->plugins);
+	cherokee_handler_table_free (vserver->plugins);
 	vserver->plugins = NULL;
 
 	for (i=0; i<=http_type_400_max; i++) {
@@ -141,11 +141,15 @@ cherokee_virtual_server_clean (cherokee_virtual_server_t *vserver)
 
 
 ret_t 
-cherokee_virtual_server_set (cherokee_virtual_server_t *vserver, char *web_dir,  char *handler_name, cherokee_plugin_table_entry_t *plugin_entry)
+cherokee_virtual_server_set (cherokee_virtual_server_t *vserver, char *web_dir,  char *handler_name, cherokee_handler_table_entry_t *plugin_entry)
 {
 	ret_t ret;
 
-	ret = cherokee_plugin_table_add (vserver->plugins, web_dir, plugin_entry);
+#if 0
+	printf ("vserver::set webdir:'%s' -> %p\n", web_dir, plugin_entry);
+#endif
+
+	ret = cherokee_handler_table_add (vserver->plugins, web_dir, plugin_entry);
 	if (ret != ret_ok) {
 		switch (ret) {
 		case ret_file_not_found:
