@@ -33,20 +33,20 @@
 #include <gnutls/gnutls.h>
 #endif
 
-#include "plugin_table.h"
-#include "plugin_table_entry.h"
+#include "handler_table.h"
+#include "handler_table_entry.h"
 #include "logger.h"
 
 
 typedef struct {
-	char                    *domain;       /* Domain name. Eg: www.alobbs.com */
-	cherokee_plugin_table_t *plugins;      /* plugin-to-path. Eg: (/public, common) */
+	char                     *domain;       /* Domain name. Eg: www.alobbs.com */
+	cherokee_handler_table_t *plugins;      /* plugin-to-path. Eg: (/public, common) */
 
-	char                    *root;         /* Document root. Eg: /var/www */
-	int                      root_len;     /* Document root length */
+	char                     *root;         /* Document root. Eg: /var/www */
+	int                       root_len;     /* Document root length */
 
-	cherokee_logger_t       *logger;
-	cherokee_table_t        *logger_props;
+	cherokee_logger_t        *logger;
+	cherokee_table_t         *logger_props;
 
 	struct {                               /* HTTP Error codes: 400 .. 417 */
 		char *file;
@@ -77,7 +77,7 @@ ret_t cherokee_virtual_server_new   (cherokee_virtual_server_t **vserver);
 ret_t cherokee_virtual_server_free  (cherokee_virtual_server_t  *vserver);
 ret_t cherokee_virtual_server_clean (cherokee_virtual_server_t  *vserver);
 
-ret_t cherokee_virtual_server_set   (cherokee_virtual_server_t  *vserver, char *web_dir, char *handler_name, cherokee_plugin_table_entry_t *plugin_entry);
+ret_t cherokee_virtual_server_set   (cherokee_virtual_server_t  *vserver, char *web_dir, char *handler_name, cherokee_handler_table_entry_t *plugin_entry);
 
 ret_t cherokee_virtual_server_get_error_page (cherokee_virtual_server_t *vserver, cherokee_http_t error_code, char **filename_ref);
 ret_t cherokee_virtual_server_get_error_url  (cherokee_virtual_server_t *vserver, cherokee_http_t error_code, char **url_ref);
